@@ -15,7 +15,8 @@ from ...specter_error import SpecterError
 
 from ...util.fee_estimation import get_fees
 
-from .. import auth
+from .. import token_auth
+from .resource_jwt import JWTResource, JWTResourceById
 from .resource_healthz import ResourceLiveness, ResourceReadyness
 from .resource_psbt import ResourcePsbt
 from .resource_specter import ResourceSpecter
@@ -30,7 +31,7 @@ class ResourceWallet(SecureResource):
     endpoints = ["/v1alpha/wallets/<wallet_alias>/"]
 
     def get(self, wallet_alias):
-        user = auth.current_user()
+        user = token_auth.current_user()
         try:
             wallet: Wallet = app.specter.user_manager.get_user(
                 user
@@ -42,7 +43,7 @@ class ResourceWallet(SecureResource):
             logger.error(se)
             return abort(500)
 
-        wallet.get_balance()
+        wallet.update_balance()
         wallet.check_utxo()
         wallet.check_unused()
 
