@@ -1,19 +1,19 @@
 import hashlib
 
 # from ..device import Device
+from . import DeviceTypes
 from .coldcard import ColdCard
 from hwilib.psbt import PSBT
 from binascii import a2b_base64
 from ..util import bcur
-from ..util.base43 import b43_encode
 from ..util.xpub import get_xpub_fingerprint
 from ..helpers import to_ascii20
 
 
 class Cobo(ColdCard):
-    device_type = "cobo"
+    device_type = DeviceTypes.COBO
     name = "Cobo Vault"
-    icon = "cobo_icon.svg"
+    icon = "img/devices/cobo_icon.svg"
 
     hwi_support = False
     sd_card_support = True
