@@ -67,6 +67,9 @@ class ConfigManager(GenericDataManager):
             "hide_sensitive_info": False,
             "autohide_sensitive_info_timeout_minutes": None,
             "autologout_timeout_hours": 4,
+            "testing": {
+                "allow_threading_for_testing": False,
+            },
             # TODO: remove
             "bitcoind": False,
         }
