@@ -1,25 +1,30 @@
 import copy
 import json
+import logging
 import random
 import re
 
 from cryptoadvance.specter.devices.device_types import DeviceTypes
 from flask import Blueprint, Flask
 from flask import current_app as app
-from flask import flash, jsonify, redirect, render_template, request, url_for
+from flask import jsonify, redirect, render_template, request, url_for
 from flask_babel import lazy_gettext as _
 from flask_login import current_user, login_required
 from mnemonic import Mnemonic
 
 from ..devices.bitcoin_core import BitcoinCore
 from ..helpers import is_testnet
-from ..util.mnemonic import generate_mnemonic, validate_mnemonic
 from ..key import Key
 from ..managers.device_manager import get_device_class
+from ..server_endpoints import flash
 from ..specter_error import handle_exception
+from ..util.mnemonic import generate_mnemonic, validate_mnemonic
 from ..wallet import purposes
 
+logger = logging.getLogger(__name__)
+
 rand = random.randint(0, 1e32)  # to force style refresh
+logger = logging.getLogger(__name__)
 
 # Setup endpoint blueprint
 devices_endpoint = Blueprint("devices_endpoint", __name__)
@@ -40,6 +45,8 @@ def new_device_type():
 @devices_endpoint.route("/new_device_keys/<device_type>/", methods=["GET", "POST"])
 @login_required
 def new_device_keys(device_type):
+    device_class = get_device_class(device_type)
+    template = device_class.template
     err = None
     mnemonic = ""
     passphrase = ""
@@ -62,7 +69,7 @@ def new_device_keys(device_type):
                 err = _("Device name cannot be empty")
             elif device_name in app.specter.device_manager.devices_names:
                 err = _("Device with this name already exists")
-        xpubs_rows_count = int(request.form["xpubs_rows_count"]) + 1
+        xpubs_rows_count = int(request.form.get("xpubs_rows_count", 0)) + 1
         keys = []
         paths = []
         keys_purposes = []
@@ -81,6 +88,8 @@ def new_device_keys(device_type):
                 except:
                     err = _("Failed to parse these xpubs") + ":\n" + "\n".join(xpub)
                     break
+        if device_type == "electrum":
+            keys.append(Key.parse_xpub(request.form["master_pub_key"]))
         if not keys and not err:
             if device_type in [
                 DeviceTypes.BITCOINCORE,
@@ -174,13 +183,15 @@ def new_device_keys(device_type):
                 )
 
     return render_template(
-        "device/new_device/new_device_keys.jinja",
-        device_class=get_device_class(device_type),
+        template,
+        device_class=device_class,
         mnemonic=mnemonic,
         passphrase=passphrase,
         file_password=file_password,
         range_start=range_start,
         range_end=range_end,
+        device_name=request.form.get("device_name", ""),
+        master_pub_key=request.form.get("master_pub_key", ""),
         existing_device=app.specter.device_manager.get_by_alias(existing_device)
         if existing_device
         else None,
@@ -204,7 +215,7 @@ def new_device_mnemonic(device_type):
             err = _(
                 "Invalid mnemonic entered: Must contain either: 12, 15, 18, 21, or 24 words."
             )
-        if not validate_mnemonic(words=request.form["mnemonic"]):
+        if not validate_mnemonic(request.form["mnemonic"]):
             err = _("Invalid mnemonic entered.")
         range_start = int(request.form["range_start"])
         range_end = int(request.form["range_end"])
@@ -267,6 +278,7 @@ def device_blinding_key(device_alias):
                 + ("?newdevice=true" if new_device else "")
             )
         except Exception as e:
+            logger.exception(e)
             flash(
                 _("Invalid master blinding key! It should be in WIF or hex format."),
                 "error",
@@ -325,7 +337,7 @@ def new_device_manual():
                     "Invalid mnemonic entered: Must contain either: 12, 15, 18, 21, or 24 words."
                 )
 
-            if not validate_mnemonic(words=request.form["mnemonic"]):
+            if not validate_mnemonic(request.form["mnemonic"]):
                 err = _("Invalid mnemonic entered.")
             range_start = int(request.form["range_start"])
             range_end = int(request.form["range_end"])
@@ -496,6 +508,12 @@ def device(device_alias):
         )
 
     device.keys.sort(key=sort_accounts, reverse=False)
+
+    # For message signing
+    origin = request.args.get("origin", "")
+    address = request.args.get("address", "")
+    derivation_path = request.args.get("derivation_path", "")
+
     return render_template(
         "device/device.jinja",
         device=device,
@@ -505,4 +523,7 @@ def device(device_alias):
         error=err,
         specter=app.specter,
         rand=rand,
+        origin=origin,
+        address=address,
+        derivation_path=derivation_path,
     )
