@@ -14,7 +14,11 @@ from flask_login import login_required, current_user
 from flask import current_app as app
 from ..rpc import get_default_datadir
 from ..node import Node
-from ..specter_error import ExtProcTimeoutException
+from ..specter_error import (
+    ExtProcTimeoutException,
+    BrokenCoreConnectionException,
+    SpecterError,
+)
 from ..util.shell import get_last_lines_from_file
 from ..server_endpoints import flash
 
@@ -34,7 +38,16 @@ nodes_endpoint = Blueprint("nodes_endpoint", __name__)
 def node_settings(node_alias):
     if node_alias:
         try:
-            node = app.specter.node_manager.get_by_alias(node_alias)
+            node: Node = app.specter.node_manager.get_by_alias(node_alias)
+            if not node.is_specter_core_object:
+                return redirect(
+                    url_for(
+                        # This is a convention which should be documented
+                        # Maybe we should do that differently
+                        f"{node.blueprint}.node_settings",
+                        node_alias=node.alias,
+                    )
+                )
             if not node.external_node:
                 return redirect(
                     url_for(
@@ -42,7 +55,8 @@ def node_settings(node_alias):
                         node_alias=node.alias,
                     )
                 )
-        except:
+        except SpecterError as se:
+            assert str(se).endswith("does not exist!")
             return render_template(
                 "base.jinja", error=_("Node not found"), specter=app.specter, rand=rand
             )
@@ -57,7 +71,6 @@ def node_settings(node_alias):
                 "port": 8332,
                 "host": "localhost",
                 "protocol": "http",
-                "external_node": True,
             },
             app.specter.node_manager,
         )
@@ -138,13 +151,11 @@ def node_settings(node_alias):
                 port,
                 host,
                 protocol,
-                node.external_node,
                 node.fullpath,
                 "BTC",
                 node.manager,
             )
             test = node.test_rpc()
-
             if "tests" in test:
                 # If any test has failed, we notify the user that the test has not passed
                 if not test["tests"] or False in list(test["tests"].values()):
@@ -155,7 +166,7 @@ def node_settings(node_alias):
                 flash(_("Test failed: {}").format(test["err"]), "error")
         elif action == "save":
             if not node_alias:
-                if node.name in app.specter.node_manager.nodes:
+                if node.name in app.specter.node_manager.nodes_names:
                     flash(
                         _(
                             "Node with this name already exists, please choose a different name."
@@ -170,7 +181,7 @@ def node_settings(node_alias):
                         specter=app.specter,
                         rand=rand,
                     )
-                node = app.specter.node_manager.add_node(
+                node = app.specter.node_manager.add_external_node(
                     "BTC",
                     node.name,
                     autodetect,
@@ -180,7 +191,6 @@ def node_settings(node_alias):
                     port,
                     host,
                     protocol,
-                    node.external_node,
                 )
                 app.specter.update_active_node(node.alias)
                 return redirect(
@@ -197,9 +207,9 @@ def node_settings(node_alias):
                 protocol=protocol,
             )
             if not success:
-                flash(_("Failed connecting to the node"), "error")
-            if app.specter.active_node_alias == node.alias:
-                app.specter.check()
+                flash(_("Saving failed: no connection to node"), "error")
+            if success:
+                return redirect(url_for("welcome_endpoint.index"))
 
     return render_template(
         "node/node_settings.jinja",
@@ -261,7 +271,7 @@ def internal_node_settings(node_alias):
                 node.rename(node_name)
         elif action == "forget":
             if not node_alias:
-                flash(_("Failed to deleted node. Node isn't saved"), "error")
+                flash(_("Failed to delete node. Node isn't saved"), "error")
             elif len(app.specter.node_manager.nodes) > 1:
                 node.stop()
                 app.specter.node_manager.delete_node(node, app.specter)
@@ -317,6 +327,7 @@ def internal_node_settings(node_alias):
                     )
                 )
             except Exception as e:
+                logger.exception(e)
                 flash(_("Failed to remove Bitcoin Core, error: {}").format(e), "error")
         elif action == "upgrade_bitcoind":
             if node.version != app.config["INTERNAL_BITCOIND_VERSION"]:
@@ -325,6 +336,7 @@ def internal_node_settings(node_alias):
                         app.specter, app.config["INTERNAL_BITCOIND_VERSION"]
                     )
                 except Exception as e:
+                    logger.exception(e)
                     flash(
                         _("Failed to upgrade Bitcoin Core version, error: {}").format(
                             e
@@ -360,5 +372,7 @@ def internal_node_logs(node_alias):
 @login_required
 def switch_node():
     node_alias = request.form["node_alias"]
+    node_name = app.specter.node_manager.get_name_from_alias(node_alias)
     app.specter.update_active_node(node_alias)
-    return redirect(url_for("nodes_endpoint.node_settings", node_alias=node_alias))
+    flash(_(f"Switched to use {node_name} as node."))
+    return redirect(url_for("index"))
