@@ -15,38 +15,38 @@ from sys import exit
 from urllib.parse import urlparse
 
 import requests
+from cryptoadvance.specter.devices.device_types import DeviceTypes
+from cryptoadvance.specter.services.service_encrypted_storage import (
+    ServiceEncryptedStorageManager,
+    ServiceUnencryptedStorageManager,
+)
 from requests.exceptions import ConnectionError
+from stem import SocketError
 from stem.control import Controller
 from urllib3.exceptions import NewConnectionError
 
-from cryptoadvance.specter.devices.device_types import DeviceTypes
-
-from .helpers import clean_psbt, deep_update, is_liquid, is_testnet, get_asset_label
+from .helpers import clean_psbt, deep_update, get_asset_label, is_liquid
 from .internal_node import InternalNode
 from .liquid.rpc import LiquidRPC
 from .managers.config_manager import ConfigManager
 from .managers.node_manager import NodeManager
 from .managers.otp_manager import OtpManager
+from .managers.service_manager import ServiceManager
 from .managers.user_manager import UserManager
 from .managers.wallet_manager import WalletManager
 from .node import Node
 from .persistence import read_json_file, write_json_file, write_node
 from .process_controller.bitcoind_controller import BitcoindPlainController
-from .rpc import (
-    BitcoinRPC,
-    RpcError,
-    autodetect_rpc_confs,
-    detect_rpc_confs,
-    get_default_datadir,
-)
+from .rpc import BitcoinRPC, RpcError, get_default_datadir
+from .services.service import devstatus_alpha, devstatus_beta, devstatus_prod
 from .specter_error import ExtProcTimeoutException, SpecterError
 from .tor_daemon import TorDaemonController
 from .user import User
 from .util.checker import Checker
-from .util.version import VersionChecker
 from .util.price_providers import update_price
 from .util.setup_states import SETUP_STATES
 from .util.tor import get_tor_daemon_suffix
+from .util.version import VersionChecker
 
 logger = logging.getLogger(__name__)
 
@@ -58,7 +58,18 @@ class Specter:
     lock = threading.Lock()
     _default_asset = None
 
-    def __init__(self, data_folder="./data", config={}, internal_bitcoind_version=""):
+    def __init__(
+        self,
+        data_folder="./data",
+        config={},
+        internal_bitcoind_version="",
+        checker_threads=True,
+        initialize=True,
+    ):
+        """Very basic Initialisation of the Specter Object. Will, by default call specter.initialize() shortly after
+        This might be unwanted (e.g. in server.py) in order to apply specter.service_manager so that all the
+        managers can make callbacks in the initialize method.
+        """
         if data_folder.startswith("~"):
             data_folder = os.path.expanduser(data_folder)
         data_folder = os.path.abspath(data_folder)
@@ -68,31 +79,59 @@ class Specter:
             os.makedirs(data_folder)
 
         self.data_folder = data_folder
+        self._config = config
+        self._internal_bitcoind_version = internal_bitcoind_version
+        self._checker_threads = checker_threads
+        if initialize:
+            self.initialize()
 
+    def initialize(self):
+        """Runs the checker_treads, instantiates all the managers and attach them to its attributes"""
         self.user_manager = UserManager(
             self
         )  # has to come before calling VersionChecker()
 
         # version checker
         # checks for new versions once per hour
+        logger.info("Instantiate VersionChecker")
         self.version = VersionChecker(specter=self)
-        self.version.start()
+        if self._checker_threads:
+            self.version.start()
 
-        self._config_manager = ConfigManager(self.data_folder, config)
+        logger.info("Instantiate ConfigManager")
+        self._config_manager = ConfigManager(self.data_folder, self._config)
 
-        self.internal_bitcoind_version = internal_bitcoind_version
+        self.internal_bitcoind_version = self._internal_bitcoind_version
 
         # Migrating from Specter 1.3.1 and lower (prior to the node manager)
         self.migrate_old_node_format()
 
+        logger.info(
+            f"Instantiate NodeManager with node alias: {self.active_node_alias}."
+        )
         self.node_manager = NodeManager(
             proxy_url=self.proxy_url,
             only_tor=self.only_tor,
             active_node=self.active_node_alias,
             bitcoind_path=self.bitcoind_path,
-            internal_bitcoind_version=internal_bitcoind_version,
+            internal_bitcoind_version=self._internal_bitcoind_version,
             data_folder=os.path.join(self.data_folder, "nodes"),
+            service_manager=self.service_manager
+            if hasattr(self, "service_manager")
+            else None,
         )
+        try:
+            logger.debug(
+                f"This is the active node in the node manager: {self.node_manager.active_node}"
+            )
+        except SpecterError as e:
+            if str(e).endswith("does not exist!"):
+                logger.warning(
+                    f"Current Node doesn't exist. Switching over to node {self.node_manager.DEFAULT_ALIAS}."
+                )
+                self.update_active_node(self.node_manager.DEFAULT_ALIAS)
+            else:
+                raise e
 
         self.torbrowser_path = os.path.join(
             self.data_folder, f"tor-binaries/tor{get_tor_daemon_suffix()}"
@@ -121,21 +160,34 @@ class Specter:
             if os.path.isfile(self.torbrowser_path):
                 self.tor_daemon.start_tor_daemon()
         except Exception as e:
-            logger.error(e)
+            logger.exception(e)
 
         self.update_tor_controller()
         self.checker = Checker(lambda: self.check(check_all=True), desc="health")
-        self.checker.start()
+        if self._checker_threads:
+            self.checker.start()
         self.price_checker = Checker(
             lambda: update_price(self, self.user), desc="price"
         )
-        if self.price_check and self.price_provider:
+        if self.price_check and self.price_provider and self._checker_threads:
             self.price_checker.start()
 
-        # This is for CTRL-C --> SIGINT
-        signal.signal(signal.SIGINT, self.cleanup_on_exit)
-        # This is for kill $pid --> SIGTERM
-        signal.signal(signal.SIGTERM, self.cleanup_on_exit)
+        # Configuring the two different storages (Universal json-files)
+        logger.info("Instantiate ServiceEncryptedStorageManager")
+        self.service_encrypted_storage_manager = ServiceEncryptedStorageManager(
+            self.data_folder, self.user_manager
+        )
+        logger.info("Instantiate ServiceUnencryptedStorageManager")
+        self.service_unencrypted_storage_manager = ServiceUnencryptedStorageManager(
+            self.data_folder, self.user_manager
+        )
+
+        if threading.current_thread() is threading.main_thread():
+            # Python signal handlers are always executed in the main Python thread and only the main thread is allowed to set a new signal handler.
+            # This is for CTRL-C --> SIGINT
+            signal.signal(signal.SIGINT, self.cleanup_on_exit)
+            # This is for kill $pid --> SIGTERM
+            signal.signal(signal.SIGTERM, self.cleanup_on_exit)
 
     def cleanup_on_exit(self, signum=0, frame=0):
         if self._tor_daemon:
@@ -182,7 +234,7 @@ class Specter:
                 u.check()
 
     @property
-    def node(self):
+    def node(self) -> Node:
         try:
             return self.node_manager.active_node
         except SpecterError as e:
@@ -260,8 +312,10 @@ class Specter:
     # mark
     def update_active_node(self, node_alias):
         """update the current active node to use"""
+        self.node_manager.switch_node(
+            node_alias
+        )  # If the node alias doesn't exist, this throws an exception preventing incorrectly updating the config.
         self.config_manager.update_active_node(node_alias)
-        self.node_manager.switch_node(node_alias)
         self.check()
 
     def update_setup_status(self, software_name, stage):
@@ -362,7 +416,7 @@ class Specter:
             self._tor_controller.authenticate(
                 password=self.config.get("torrc_password", "")
             )
-        except Exception as e:
+        except SocketError as e:
             logger.warning(f"Failed to connect to Tor control port. Error: {e}")
             self._tor_controller = None
 
@@ -428,7 +482,11 @@ class Specter:
     def update_alt_symbol(self, alt_symbol, user):
         self.config_manager.update_alt_symbol(alt_symbol, user)
 
-    # mark logic!
+    def update_services(self, services):
+        """takes a list of service_names which should be activated"""
+        self.config["services"] = services
+        self._save()
+
     def update_merkleproof_settings(self, validate_bool):
         if validate_bool is True and self.info.get("pruned") is True:
             validate_bool = False
@@ -628,7 +686,7 @@ class Specter:
 
     @property
     def autohide_sensitive_info_timeout(self):
-        return self.user_config.get("autohide_sensitive_info_timeout_minutes", 20)
+        return self.user_config.get("autohide_sensitive_info_timeout_minutes", None)
 
     @property
     def autologout_timeout(self):
@@ -724,8 +782,8 @@ class Specter:
                 old_rpc.get("port", None),
                 old_rpc.get("host", "localhost"),
                 old_rpc.get("protocol", "http"),
-                True,
                 os.path.join(os.path.join(self.data_folder, "nodes"), "default.json"),
+                "BTC",
                 self,
             )
             logger.info(f"persisting {node} in migrate_old_node_format")
