@@ -37,7 +37,7 @@ def which(program):
             if is_exe(exe_file):
                 logger.debug("Found %s executable in %s" % (program, path))
                 return exe_file
-    raise Exception("Couldn't find executable %s" % program)
+    raise Exception(f"Couldn't find executable {program} cwd={os.getcwd()}")
 
 
 # should work in all python versions
@@ -52,12 +52,22 @@ def run_shell(cmd):
         stdout, stderr = proc.communicate()
         return {"code": proc.returncode, "out": stdout, "err": stderr}
     except Exception as e:
+        logger.exception(e)
         return {"code": 0xF00DBABE, "out": b"", "err": e}
 
 
-def get_last_lines_from_file(file_localtion, x=50):
+def get_last_lines_from_file(file_location, x=50):
     """returns an array of the last x lines of a file"""
-    with open(file_localtion, "r") as the_file:
+    with open(file_location, "r") as the_file:
         lines = the_file.readlines()
         last_lines = lines[-x:]
     return last_lines
+
+
+def grep(file_location, search_line):
+    """returns true if any like in that file endswith search_line"""
+    with open(file_location, "r") as the_file:
+        for line in the_file.readlines():
+            if line.strip().endswith(search_line):
+                return True
+    return False
